==> img0ch-2.1.21.tar.bz2: img0ch/_template/zeromin2/vthread_load_setting.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/vthread_side_menu.cs" ?>

<div id="main">

<form id="vthreadSettingContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:Subject ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=load_setting&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">仮想スレッド内の独自設定</a><br />
</div>

<h1>仮想スレッド内の独自設定</h1>

<?cs if:Code0 ?>
<?cs if:Done_vthread_save_setting ?><div class="noticeSuccess" id="notify"><p>独自設定情報を更新しました</p></div>
<?cs else ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<ul>
<li>設定されていない項目はSETTING.TXTに従って設定されます</li>
<li>数値項目がSETTING.TXTより大きい場合はSETTING.TXTのデフォルト値に再設定されます</li>
<li>文字項目は最大<?cs var:html_escape(SettingStringLengthMax) ?>バイトまで設定できます</li>
</ul>

<div class="InlineLabels">
<label for="BBS_COLUMN_NUMBER">一行あたりの最大文字数</label>
<input id="BBS_COLUMN_NUMBER" type="text" name="BBS_COLUMN_NUMBER" value="<?cs var:html_escape(BBS_COLUMN_NUMBER) ?>" /><br />
<label for="BBS_DATMAX">スレッドの最大容量</label>
<input id="BBS_DATMAX" type="text" name="BBS_DATMAX" value="<?cs var:html_escape(BBS_DATMAX) ?>" /><br />
<label for="BBS_LINE_NUMBER">本文の最大改行数</label>
<input id="BBS_LINE_NUMBER" type="text" name="BBS_LINE_NUMBER" value="<?cs var:html_escape(BBS_LINE_NUMBER) ?>" /><br />
<label for="BBS_MAIL_COUNT">メール欄の最大文字数(バイト単位)</label>
<input id="BBS_MAIL_COUNT" type="text" name="BBS_MAIL_COUNT" value="<?cs var:html_escape(BBS_MAIL_COUNT) ?>" /><br />
<label for="BBS_MESSAGE_COUNT">本文の最大文字数(バイト単位)</label>
<input id="BBS_MESSAGE_COUNT" type="text" name="BBS_MESSAGE_COUNT" value="<?cs var:html_escape(BBS_MESSAGE_COUNT) ?>"><br />
<label for="BBS_NAME_COUNT">名前欄の最大文字数(バイト単位)</label>
<input id="BBS_NAME_COUNT" type="text" name="BBS_NAME_COUNT" value="<?cs var:html_escape(BBS_NAME_COUNT) ?>"><br />
<label for="BBS_RES_MAX">最大レス数</label>
<input id="BBS_RES_MAX" type="text" name="BBS_RES_MAX" value="<?cs var:html_escape(BBS_RES_MAX) ?>"><br />
<label for="BBS_NONAME_NAME">名無しのデフォルト名</label>
<input id="BBS_NONAME_NAME" type="text" name="BBS_NONAME_NAME" value="<?cs var:html_escape(BBS_NONAME_NAME) ?>"><br />
<label for="BBS_DELETE_NAME">削除時の文言(仮想スレッド管理での削除時のみ有効)</label>
<input id="BBS_DELETE_NAME" type="text" name="BBS_DELETE_NAME" value="<?cs var:html_escape(BBS_DELETE_NAME) ?>"><br />
<label for="THREAD_POSITION">スレッドの位置</label>
<input id="THREAD_POSITION" type="text" name="THREAD_POSITION" value="<?cs var:html_escape(THREAD_POSITION) ?>"><br />
<input type="submit" name="s" value="更新" />
</div>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="vthread" />
<input type="hidden" name="method" value="save_setting" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>" />
<input type="hidden" name="OK" value="load_setting" />
<input type="hidden" name="NG" value="load_setting" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.1.9.tar.bz2: img0ch/_template/zeromin2/vthread_load_setting.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/vthread_side_menu.cs" ?>

<div id="main">

<form id="vthreadSettingContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:Subject ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=load_setting&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">仮想スレッド内の独自設定</a><br />
</div>

<h1>仮想スレッド内の独自設定</h1>

<?cs if:Code0 ?>
<?cs if:Done_vthread_save_setting ?><div class="noticeSuccess" id="notify"><p>独自設定情報を更新しました</p></div>
<?cs else ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<ul>
<li>設定されていない項目はSETTING.TXTに従って設定されます</li>
<li>数値項目がSETTING.TXTより大きい場合はSETTING.TXTのデフォルト値に再設定されます</li>
<li>文字項目は最大<?cs var:html_escape(SettingStringLengthMax) ?>バイトまで設定できます</li>
</ul>

<div class="InlineLabels">
<label for="BBS_COLUMN_NUMBER">一行あたりの最大文字数</label>
<input id="BBS_COLUMN_NUMBER" type="text" name="BBS_COLUMN_NUMBER" value="<?cs var:html_escape(BBS_COLUMN_NUMBER) ?>" /><br />
<label for="BBS_DATMAX">スレッドの最大容量</label>
<input id="BBS_DATMAX" type="text" name="BBS_DATMAX" value="<?cs var:html_escape(BBS_DATMAX) ?>" /><br />
<label for="BBS_LINE_NUMBER">本文の最大改行数</label>
<input id="BBS_LINE_NUMBER" type="text" name="BBS_LINE_NUMBER" value="<?cs var:html_escape(BBS_LINE_NUMBER) ?>" /><br />
<label for="BBS_MAIL_COUNT">メール欄の最大文字数(バイト単位)</label>
<input id="BBS_MAIL_COUNT" type="text" name="BBS_MAIL_COUNT" value="<?cs var:html_escape(BBS_MAIL_COUNT) ?>" /><br />
<label for="BBS_MESSAGE_COUNT">本文の最大文字数(バイト単位)</label>
<input id="BBS_MESSAGE_COUNT" type="text" name="BBS_MESSAGE_COUNT" value="<?cs var:html_escape(BBS_MESSAGE_COUNT) ?>" /><br />
<label for="BBS_NAME_COUNT">名前欄の最大文字数(バイト単位)</label>
<input id="BBS_NAME_COUNT" type="text" name="BBS_NAME_COUNT" value="<?cs var:html_escape(BBS_NAME_COUNT) ?>" /><br />
<label for="BBS_RES_MAX">最大レス数</label>
<input id="BBS_RES_MAX" type="text" name="BBS_RES_MAX" value="<?cs var:html_escape(BBS_RES_MAX) ?>" /><br />
<label for="BBS_NONAME_NAME">名無しのデフォルト名</label>
<input id="BBS_NONAME_NAME" type="text" name="BBS_NONAME_NAME" value="<?cs var:html_escape(BBS_NONAME_NAME) ?>" /><br />
<label for="BBS_DELETE_NAME">削除時の文言(仮想スレッド管理での削除時のみ有効)</label>
<input id="BBS_DELETE_NAME" type="text" name="BBS_DELETE_NAME" value="<?cs var:html_escape(BBS_DELETE_NAME) ?>" /><br />
<label for="THREAD_POSITION">スレッドの位置</label>
<input id="THREAD_POSITION" type="text" name="THREAD_POSITION" value="<?cs var:html_escape(THREAD_POSITION) ?>" /><br />
<label for="BBS_READONLY">キャップのみ書き込み可能にする</label>
<input id="BBS_READONLY" type="checkbox" name="BBS_READONLY" value="caps" <?cs if:BBS_READONLY ?>checked="checked"<?cs /if ?>/>キャップのみ許可<br />
<input type="submit" name="s" value="更新" />
</div>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="vthread" />
<input type="hidden" name="method" value="save_setting" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>" />
<input type="hidden" name="OK" value="load_setting" />
<input type="hidden" name="NG" value="load_setting" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
